var searchData=
[
  ['progress_2ecc',['progress.cc',['../sample_2progress_2progress_8cc.html',1,'']]],
  ['readme_2eh',['readme.h',['../search_2analyzer_2readme_8h.html',1,'']]],
  ['readme_2eh',['readme.h',['../stat_2readme_8h.html',1,'']]],
  ['readme_2eh',['readme.h',['../state_2readme_8h.html',1,'']]],
  ['readme_2eh',['readme.h',['../search_2readme_8h.html',1,'']]],
  ['sacrificecheck_2eh',['sacrificeCheck.h',['../sacrificeCheck_8h.html',1,'']]],
  ['safedropmajorpiece_2eh',['safeDropMajorPiece.h',['../safeDropMajorPiece_8h.html',1,'']]],
  ['safemove_2ecc',['safeMove.cc',['../safeMove_8cc.html',1,'']]],
  ['safemove_2eh',['safeMove.h',['../safeMove_8h.html',1,'']]],
  ['searchbase_2eh',['searchBase.h',['../searchBase_8h.html',1,'']]],
  ['searchinfo_2eh',['searchInfo.h',['../searchInfo_8h.html',1,'']]],
  ['searchmonitor_2ecc',['searchMonitor.cc',['../searchMonitor_8cc.html',1,'']]],
  ['searchmonitor_2eh',['searchMonitor.h',['../searchMonitor_8h.html',1,'']]],
  ['searchplayer_2ecc',['searchPlayer.cc',['../searchPlayer_8cc.html',1,'']]],
  ['searchplayer_2eh',['searchPlayer.h',['../searchPlayer_8h.html',1,'']]],
  ['searchplayer_2etcc',['searchPlayer.tcc',['../searchPlayer_8tcc.html',1,'']]],
  ['searchrecorder_2ecc',['searchRecorder.cc',['../searchRecorder_8cc.html',1,'']]],
  ['searchrecorder_2eh',['searchRecorder.h',['../searchRecorder_8h.html',1,'']]],
  ['searchstate2_2ecc',['searchState2.cc',['../searchState2_8cc.html',1,'']]],
  ['searchstate2_2eh',['searchState2.h',['../searchState2_8h.html',1,'']]],
  ['searchtable_2eh',['searchTable.h',['../searchTable_8h.html',1,'']]],
  ['searchtimer_2ecc',['searchTimer.cc',['../searchTimer_8cc.html',1,'']]],
  ['searchtimer_2eh',['searchTimer.h',['../searchTimer_8h.html',1,'']]],
  ['searchwindow_2eh',['searchWindow.h',['../searchWindow_8h.html',1,'']]],
  ['see_2dperf_2ecc',['see-perf.cc',['../see-perf_8cc.html',1,'']]],
  ['see_2ecc',['see.cc',['../see_8cc.html',1,'']]],
  ['see_2eh',['see.h',['../see_8h.html',1,'']]],
  ['sendoffsquare_2ecc',['sendOffSquare.cc',['../sendOffSquare_8cc.html',1,'']]],
  ['sendoffsquare_2eh',['sendOffSquare.h',['../sendOffSquare_8h.html',1,'']]],
  ['sennichite_2ecc',['sennichite.cc',['../sennichite_8cc.html',1,'']]],
  ['sennichite_2eh',['sennichite.h',['../sennichite_8h.html',1,'']]],
  ['shadoweffect_2ecc',['shadowEffect.cc',['../shadowEffect_8cc.html',1,'']]],
  ['shadoweffect_2eh',['shadowEffect.h',['../shadowEffect_8h.html',1,'']]],
  ['shouldpromotecut_2eh',['shouldPromoteCut.h',['../shouldPromoteCut_8h.html',1,'']]],
  ['show_2deffect_2ecc',['show-effect.cc',['../show-effect_8cc.html',1,'']]],
  ['show_2deval_2ecc',['show-eval.cc',['../show-eval_8cc.html',1,'']]],
  ['show_2dipx_2dresult_2ecc',['show-ipx-result.cc',['../show-ipx-result_8cc.html',1,'']]],
  ['show_2dipx_2ecc',['show-ipx.cc',['../show-ipx_8cc.html',1,'']]],
  ['show_2dki2_2ecc',['show-ki2.cc',['../show-ki2_8cc.html',1,'']]],
  ['show_2dmoves_2ecc',['show-moves.cc',['../show-moves_8cc.html',1,'']]],
  ['show_2dprogresseval_2ecc',['show-progresseval.cc',['../show-progresseval_8cc.html',1,'']]],
  ['show_2dsibling_2ecc',['show-sibling.cc',['../show-sibling_8cc.html',1,'']]],
  ['show_5frepetition_2ecc',['show_repetition.cc',['../show__repetition_8cc.html',1,'']]],
  ['showcores_2ecc',['showCores.cc',['../showCores_8cc.html',1,'']]],
  ['showmemory_2ecc',['showMemory.cc',['../showMemory_8cc.html',1,'']]],
  ['showopening_2ecc',['showOpening.cc',['../showOpening_8cc.html',1,'']]],
  ['showrecord_2ecc',['showRecord.cc',['../showRecord_8cc.html',1,'']]],
  ['signatureeffect_2ecc',['signatureEffect.cc',['../signatureEffect_8cc.html',1,'']]],
  ['signatureeffect_2eh',['signatureEffect.h',['../signatureEffect_8h.html',1,'']]],
  ['simplebettertopromote_2eh',['simpleBetterToPromote.h',['../simpleBetterToPromote_8h.html',1,'']]],
  ['simplehashrecord_2ecc',['simpleHashRecord.cc',['../simpleHashRecord_8cc.html',1,'']]],
  ['simplehashrecord_2eh',['simpleHashRecord.h',['../simpleHashRecord_8h.html',1,'']]],
  ['simplehashtable_2ecc',['simpleHashTable.cc',['../simpleHashTable_8cc.html',1,'']]],
  ['simplehashtable_2eh',['simpleHashTable.h',['../simpleHashTable_8h.html',1,'']]],
  ['simplemove_2eh',['simpleMove.h',['../simpleMove_8h.html',1,'']]],
  ['simplemoveperf_2ecc',['simpleMovePerf.cc',['../simpleMovePerf_8cc.html',1,'']]],
  ['simplepredictor_2ecc',['simplePredictor.cc',['../simplePredictor_8cc.html',1,'']]],
  ['simplepredictor_2eh',['simplePredictor.h',['../simplePredictor_8h.html',1,'']]],
  ['simplestate_2ecc',['simpleState.cc',['../simpleState_8cc.html',1,'']]],
  ['simplestate_2eh',['simpleState.h',['../simpleState_8h.html',1,'']]],
  ['simplestate_2etcc',['simpleState.tcc',['../simpleState_8tcc.html',1,'']]],
  ['sjis2euc_2ecc',['sjis2euc.cc',['../sjis2euc_8cc.html',1,'']]],
  ['sjis2euc_2eh',['sjis2euc.h',['../sjis2euc_8h.html',1,'']]],
  ['slist_2eh',['slist.h',['../slist_8h.html',1,'']]],
  ['slowbsf_2eh',['slowBsf.h',['../slowBsf_8h.html',1,'']]],
  ['sort_2ecc',['sort.cc',['../sort_8cc.html',1,'']]],
  ['sortcapturemoves_2ecc',['sortCaptureMoves.cc',['../sortCaptureMoves_8cc.html',1,'']]],
  ['sortcapturemoves_2eh',['sortCaptureMoves.h',['../sortCaptureMoves_8h.html',1,'']]],
  ['speculativeallmoves_2ecc',['speculativeAllMoves.cc',['../speculativeAllMoves_8cc.html',1,'']]],
  ['speculativeallmoves_2eh',['speculativeAllMoves.h',['../speculativeAllMoves_8h.html',1,'']]],
  ['speculativemodel_2ecc',['speculativeModel.cc',['../speculativeModel_8cc.html',1,'']]],
  ['speculativemodel_2eh',['speculativeModel.h',['../speculativeModel_8h.html',1,'']]],
  ['speculativesearchplayer_2ecc',['speculativeSearchPlayer.cc',['../speculativeSearchPlayer_8cc.html',1,'']]],
  ['speculativesearchplayer_2eh',['speculativeSearchPlayer.h',['../speculativeSearchPlayer_8h.html',1,'']]],
  ['square_2ecc',['square.cc',['../square_8cc.html',1,'']]],
  ['square_2eh',['square.h',['../square_8h.html',1,'']]],
  ['square8_2ecc',['square8.cc',['../square8_8cc.html',1,'']]],
  ['square8_2eh',['square8.h',['../square8_8h.html',1,'']]],
  ['squarecompressor_2ecc',['squareCompressor.cc',['../squareCompressor_8cc.html',1,'']]],
  ['squarecompressor_2eh',['squareCompressor.h',['../squareCompressor_8h.html',1,'']]],
  ['squaregroup_2ecc',['squareGroup.cc',['../squareGroup_8cc.html',1,'']]],
  ['squaregroup_2eh',['squareGroup.h',['../squareGroup_8h.html',1,'']]],
  ['stack_2eh',['stack.h',['../stack_8h.html',1,'']]],
  ['stateinfo_2ecc',['stateInfo.cc',['../stateInfo_8cc.html',1,'']]],
  ['stateinfo_2eh',['stateInfo.h',['../stateInfo_8h.html',1,'']]],
  ['store_2eh',['store.h',['../store_8h.html',1,'']]],
  ['storepiece_2eh',['storePiece.h',['../storePiece_8h.html',1,'']]],
  ['storeptypeosquare_2eh',['storePtypeOSquare.h',['../storePtypeOSquare_8h.html',1,'']]]
];
